JsonSchemeazkadev class
return original data json
Constructors
- JsonSchemeazkadev(Map rawData)
- return original data json
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEmpty → bool
-
Whether there is no key/value pair in the map.
no setter
- isNotEmpty → bool
-
Whether there is at least one key/value pair in the map.
no setter
- rawData ↔ Map
-
return original data json
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
cast<
R> () → R - convert to other
-
castOrNull<
R> () → R? - convert to other
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map - return original data json
-
toMap(
) → Map - return original data json
-
toString(
) → String -
return string data encode json original data
override
-
toStringPretty(
) → String - return string data encode json original data
-
utils_filter_by_keys(
List keys) → Map - return original data json
-
utils_remove_by_keys(
List keys) → Map - return original data json
-
utils_remove_by_keys_void(
List keys) → void - GeneralUniverse
-
utils_remove_by_values(
List values) → Map - return original data json
-
utils_remove_by_values_void(
List values) → void - return original data json
-
utils_remove_values_null(
) → Map - return original data json
-
utils_remove_values_null_void(
) → void - return original data json
Operators
-
operator *(
dynamic value) → void - operator map data
-
operator +(
dynamic value) → Map - operator map data
-
operator -(
dynamic value) → Map - return original data json
-
operator /(
dynamic value) → void - operator map data
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
dynamic key) → dynamic - operator map data
-
operator []=(
dynamic key, dynamic value) → void - operator map data
Static Properties
- defaultData → Map
-
return original data json
no setter
Static Methods
-
create(
{String special_type = "JsonSchemeazkadev"}) → JsonSchemeazkadev - return original data json
-
empty(
) → JsonSchemeazkadev - GeneralUniverse